IMBA_Lines={};
IMBA_Line_Data={};
--Copied from Blizzard's TaxiFrame code and modifed for IMBA

-- The following function is used with permission from Daniel Stephens <iriel@vigilance-committee.org>
TAXIROUTE_LINEFACTOR = 32/28; -- Multiplying factor for texture coordinates
TAXIROUTE_LINEFACTOR_2 = TAXIROUTE_LINEFACTOR / 2; -- Half o that

-- T        - Texture
-- C        - Canvas Frame (for anchoring)
-- sx,sy    - Coordinate of start of line
-- ex,ey    - Coordinate of end of line
-- w        - Width of line
-- relPoint - Relative point on canvas to interpret coords (Default BOTTOMLEFT)
--/script IMBA_DrawLine(IMBA_Ouro,0,0,-200,-200,32)
function IMBA_DrawLine(C, sx, sy, ex, ey, w, color)
   local T, lineNum, relPoint;
   if (not relPoint) then relPoint = "BOTTOMLEFT"; end

   if not IMBA_Lines[C:GetName()] then
	IMBA_Lines[C:GetName()]={};
	IMBA_Line_Data[C:GetName()]={};
   end

   T=nil;

   for k,v in pairs(IMBA_Lines[C:GetName()]) do
	if not v:IsShown() and not T then
		T=v;
		lineNum=k;
		T:Show();
	end
   end

	if not T then
		T=C:CreateTexture(C:GetName().."_Line"..(getn(IMBA_Lines[C:GetName()])+1), "ARTWORK");
		T:SetTexture("Interface\\AddOns\\WhiteboardNG\\textures\\line");
		tinsert(IMBA_Lines[C:GetName()],T);
		tinsert(IMBA_Line_Data[C:GetName()],{sx,sy,ex,ey,w});
	else
		IMBA_Line_Data[C:GetName()][lineNum]={sx,sy,ex,ey,w};
	end

	T:SetVertexColor(color[1],color[2],color[3],color[4]);
   -- Determine dimensions and center point of line
   local dx,dy = ex - sx, ey - sy;
   local cx,cy = (sx + ex) / 2, (sy + ey) / 2;

   -- Normalize direction if necessary
   if (dx < 0) then
      dx,dy = -dx,-dy;
   end

   -- Calculate actual length of line
   local l = sqrt((dx * dx) + (dy * dy));

   -- Quick escape if it's zero length
   if (l == 0) then
      T:SetTexCoord(0,0,0,0,0,0,0,0);
      T:SetPoint("BOTTOMLEFT", C, relPoint, cx,cy);
      T:SetPoint("TOPRIGHT",   C, relPoint, cx,cy);
      return;
   end

   -- Sin and Cosine of rotation, and combination (for later)
   local s,c = -dy / l, dx / l;
   local sc = s * c;

   -- Calculate bounding box size and texture coordinates
   local Bwid, Bhgt, BLx, BLy, TLx, TLy, TRx, TRy, BRx, BRy;
   if (dy >= 0) then
      Bwid = ((l * c) - (w * s)) * TAXIROUTE_LINEFACTOR_2;
      Bhgt = ((w * c) - (l * s)) * TAXIROUTE_LINEFACTOR_2;
      BLx, BLy, BRy = (w / l) * sc, s * s, (l / w) * sc;
      BRx, TLx, TLy, TRx = 1 - BLy, BLy, 1 - BRy, 1 - BLx;
      TRy = BRx;
   else
      Bwid = ((l * c) + (w * s)) * TAXIROUTE_LINEFACTOR_2;
      Bhgt = ((w * c) + (l * s)) * TAXIROUTE_LINEFACTOR_2;
      BLx, BLy, BRx = s * s, -(l / w) * sc, 1 + (w / l) * sc;
      BRy, TLx, TLy, TRy = BLx, 1 - BRx, 1 - BLx, 1 - BLy;
      TRx = TLy;
   end

   -- Set texture coordinates and anchors
   T:ClearAllPoints();
   T:SetTexCoord(TLx, TLy, BLx, BLy, TRx, TRy, BRx, BRy);
   T:SetPoint("BOTTOMLEFT", C, relPoint, cx - Bwid, cy - Bhgt);
   T:SetPoint("TOPRIGHT",   C, relPoint, cx + Bwid, cy + Bhgt);

   return T:GetName();
end

function IMBA_ClearLines(C)
	if(not IMBA_Lines[C:GetName()]) then return end

	for k,v in pairs(IMBA_Lines[C:GetName()]) do
		v:Hide();
	end
end

function IMBA_EraseLines(C,x,y,r)
	local Dist, xDiff, yDiff;
	r=r*r;
	if not IMBA_Lines[C:GetName()] then
		IMBA_Lines[C:GetName()]={};
		IMBA_Line_Data[C:GetName()]={};
	end
	for k,v in pairs(IMBA_Line_Data[C:GetName()]) do
		if IMBA_Lines[C:GetName()][k]:IsShown() then
			xDiff=x-v[1];
			yDiff=y-v[2];
			Dist=xDiff*xDiff+yDiff*yDiff
			if Dist<r then
				IMBA_Lines[C:GetName()][k]:Hide();
			else
				xDiff=x-v[3];
				yDiff=y-v[4];
				Dist=xDiff*xDiff+yDiff*yDiff
				if Dist<r then
					IMBA_Lines[C:GetName()][k]:Hide();
				end
			end
		end
	end
end
